@@ -32,7 +32,7 @@ from gcloud.aio.auth import AioSession, Token
 from google.api_core.retry import exponential_sleep_generator
 from googleapiclient.discovery import Resource, build
 
-from airflow.exceptions import AirflowException, AirflowNotFoundException
+from airflow.providers.common.compat.sdk import AirflowException, AirflowNotFoundException
 from airflow.providers.google.cloud.utils.datafusion import DataFusionPipelineType
 from airflow.providers.google.common.hooks.base_google import (
     PROVIDE_PROJECT_ID,
@@ -170,9 +170,9 @@ class DataFusionHook(GoogleBaseHook):
     def _check_response_status_and_data(response, message: str) -> None:
         if response.status == 404:
             raise AirflowNotFoundException(message)
-        elif response.status == 409:
+        if response.status == 409:
             raise ConflictException("Conflict: Resource is still in use.")
-        elif response.status != 200:
+        if response.status != 200:
             raise AirflowException(message)
         if response.data is None:
             raise AirflowException(
@@ -434,7 +434,7 @@ class DataFusionHook(GoogleBaseHook):
         pipeline_id: str,
         pipeline_type: DataFusionPipelineType = DataFusionPipelineType.BATCH,
         namespace: str = "default",
-    ) -> Any:
+    ) -> dict:
         url = os.path.join(
             self._base_url(instance_url, namespace),
             quote(pipeline_name),
@@ -572,8 +572,7 @@ class DataFusionAsyncHook(GoogleBaseAsyncHook):
                         raise
         if pipeline:
             return pipeline
-        else:
-            raise AirflowException("Could not retrieve pipeline. Aborting.")
+        raise AirflowException("Could not retrieve pipeline. Aborting.")
 
     async def get_pipeline(
         self,
