@@ -28,12 +28,7 @@ from looker_sdk.rtl import api_settings, auth_session, requests_transport, seria
 from looker_sdk.sdk.api40 import methods as methods40
 from packaging.version import parse as parse_version
 
-from airflow.exceptions import AirflowException
-
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.providers.common.compat.sdk import AirflowException, BaseHook
 from airflow.version import version
 
 if TYPE_CHECKING:
