@@ -24,7 +24,7 @@ from google.cloud.container_v1.types import Cluster
 from airflow.providers.google.cloud.links.base import BaseGoogleLink
 
 if TYPE_CHECKING:
-    from airflow.utils.context import Context
+    from airflow.providers.common.compat.sdk import Context
 
 KUBERNETES_BASE_LINK = "/kubernetes"
 KUBERNETES_CLUSTER_LINK = (
@@ -57,6 +57,9 @@ class KubernetesEngineClusterLink(BaseGoogleLink):
         if isinstance(cluster, dict):
             cluster = Cluster.from_json(json.dumps(cluster))
 
+        if not cluster:
+            raise ValueError("Cluster must be provided for KubernetesEngineClusterLink.")
+
         super().persist(
             context=context,
             cluster_name=cluster.name,
