@@ -26,8 +26,11 @@ from copy import deepcopy
 from typing import TYPE_CHECKING, Any
 from urllib.parse import unquote, urlsplit
 
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
+from google.cloud.devtools.cloudbuild_v1.types import Build, BuildTrigger, RepoSource
+
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.providers.google.cloud.hooks.cloud_build import CloudBuildHook
 from airflow.providers.google.cloud.links.cloud_build import (
     CloudBuildLink,
@@ -41,13 +44,12 @@ from airflow.providers.google.common.consts import GOOGLE_DEFAULT_DEFERRABLE_MET
 from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 from airflow.utils import yaml
 from airflow.utils.helpers import exactly_one
-from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.cloud.devtools.cloudbuild_v1.types import Build, BuildTrigger, RepoSource
 
 if TYPE_CHECKING:
-    from airflow.utils.context import Context
     from google.api_core.retry import Retry
 
+    from airflow.providers.common.compat.sdk import Context
+
 
 REGEX_REPO_PATH = re.compile(r"^/(?P<project_id>[^/]+)/(?P<repo_name>[^/]+)[\+/]*(?P<branch_name>[^:]+)?")
 
@@ -106,6 +108,12 @@ class CloudBuildCancelBuildOperator(GoogleCloudBaseOperator):
         self.impersonation_chain = impersonation_chain
         self.location = location
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "region": self.location,
+        }
+
     def execute(self, context: Context):
         hook = CloudBuildHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         result = hook.cancel_build(
@@ -117,14 +125,12 @@ class CloudBuildCancelBuildOperator(GoogleCloudBaseOperator):
             location=self.location,
         )
 
-        self.xcom_push(context, key="id", value=result.id)
+        context["task_instance"].xcom_push(key="id", value=result.id)
         project_id = self.project_id or hook.project_id
         if project_id:
             CloudBuildLink.persist(
                 context=context,
-                task_instance=self,
                 project_id=project_id,
-                region=self.location,
                 build_id=result.id,
             )
         return Build.to_dict(result)
@@ -208,6 +214,12 @@ class CloudBuildCreateBuildOperator(GoogleCloudBaseOperator):
             if self.build_raw.endswith(".json"):
                 self.build = json.loads(file.read())
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "region": self.location,
+        }
+
     def execute(self, context: Context):
         hook = CloudBuildHook(
             gcp_conn_id=self.gcp_conn_id,
@@ -223,7 +235,7 @@ class CloudBuildCreateBuildOperator(GoogleCloudBaseOperator):
             metadata=self.metadata,
             location=self.location,
         )
-        self.xcom_push(context, key="id", value=self.id_)
+        context["task_instance"].xcom_push(key="id", value=self.id_)
         if not self.wait:
             return Build.to_dict(
                 hook.get_build(id_=self.id_, project_id=self.project_id, location=self.location)
@@ -249,9 +261,7 @@ class CloudBuildCreateBuildOperator(GoogleCloudBaseOperator):
             if project_id:
                 CloudBuildLink.persist(
                     context=context,
-                    task_instance=self,
                     project_id=project_id,
-                    region=self.location,
                     build_id=cloud_build_instance_result.id,
                 )
             return Build.to_dict(cloud_build_instance_result)
@@ -267,14 +277,11 @@ class CloudBuildCreateBuildOperator(GoogleCloudBaseOperator):
             if project_id:
                 CloudBuildLink.persist(
                     context=context,
-                    task_instance=self,
                     project_id=project_id,
-                    region=self.location,
                     build_id=event["id_"],
                 )
             return event["instance"]
-        else:
-            raise AirflowException(f"Unexpected error in the operation: {event['message']}")
+        raise AirflowException(f"Unexpected error in the operation: {event['message']}")
 
 
 class CloudBuildCreateBuildTriggerOperator(GoogleCloudBaseOperator):
@@ -335,6 +342,12 @@ class CloudBuildCreateBuildTriggerOperator(GoogleCloudBaseOperator):
         self.impersonation_chain = impersonation_chain
         self.location = location
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "region": self.location,
+        }
+
     def execute(self, context: Context):
         hook = CloudBuildHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         result = hook.create_build_trigger(
@@ -345,21 +358,17 @@ class CloudBuildCreateBuildTriggerOperator(GoogleCloudBaseOperator):
             metadata=self.metadata,
             location=self.location,
         )
-        self.xcom_push(context, key="id", value=result.id)
+        context["task_instance"].xcom_push(key="id", value=result.id)
         project_id = self.project_id or hook.project_id
         if project_id:
             CloudBuildTriggerDetailsLink.persist(
                 context=context,
-                task_instance=self,
                 project_id=project_id,
-                region=self.location,
                 trigger_id=result.id,
             )
             CloudBuildTriggersListLink.persist(
                 context=context,
-                task_instance=self,
                 project_id=project_id,
-                region=self.location,
             )
         return BuildTrigger.to_dict(result)
 
@@ -418,6 +427,12 @@ class CloudBuildDeleteBuildTriggerOperator(GoogleCloudBaseOperator):
         self.impersonation_chain = impersonation_chain
         self.location = location
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "region": self.location,
+        }
+
     def execute(self, context: Context):
         hook = CloudBuildHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         hook.delete_build_trigger(
@@ -432,9 +447,7 @@ class CloudBuildDeleteBuildTriggerOperator(GoogleCloudBaseOperator):
         if project_id:
             CloudBuildTriggersListLink.persist(
                 context=context,
-                task_instance=self,
                 project_id=project_id,
-                region=self.location,
             )
 
 
@@ -492,6 +505,12 @@ class CloudBuildGetBuildOperator(GoogleCloudBaseOperator):
         self.impersonation_chain = impersonation_chain
         self.location = location
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "region": self.location,
+        }
+
     def execute(self, context: Context):
         hook = CloudBuildHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         result = hook.get_build(
@@ -506,9 +525,7 @@ class CloudBuildGetBuildOperator(GoogleCloudBaseOperator):
         if project_id:
             CloudBuildLink.persist(
                 context=context,
-                task_instance=self,
                 project_id=project_id,
-                region=self.location,
                 build_id=result.id,
             )
         return Build.to_dict(result)
@@ -568,6 +585,12 @@ class CloudBuildGetBuildTriggerOperator(GoogleCloudBaseOperator):
         self.impersonation_chain = impersonation_chain
         self.location = location
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "region": self.location,
+        }
+
     def execute(self, context: Context):
         hook = CloudBuildHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         result = hook.get_build_trigger(
@@ -582,9 +605,7 @@ class CloudBuildGetBuildTriggerOperator(GoogleCloudBaseOperator):
         if project_id:
             CloudBuildTriggerDetailsLink.persist(
                 context=context,
-                task_instance=self,
                 project_id=project_id,
-                region=self.location,
                 trigger_id=result.id,
             )
         return BuildTrigger.to_dict(result)
@@ -648,6 +669,12 @@ class CloudBuildListBuildTriggersOperator(GoogleCloudBaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "region": self.location,
+        }
+
     def execute(self, context: Context):
         hook = CloudBuildHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         results = hook.list_build_triggers(
@@ -663,9 +690,7 @@ class CloudBuildListBuildTriggersOperator(GoogleCloudBaseOperator):
         if project_id:
             CloudBuildTriggersListLink.persist(
                 context=context,
-                task_instance=self,
                 project_id=project_id,
-                region=self.location,
             )
         return [BuildTrigger.to_dict(result) for result in results]
 
@@ -728,6 +753,12 @@ class CloudBuildListBuildsOperator(GoogleCloudBaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "region": self.location,
+        }
+
     def execute(self, context: Context):
         hook = CloudBuildHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         results = hook.list_builds(
@@ -742,7 +773,8 @@ class CloudBuildListBuildsOperator(GoogleCloudBaseOperator):
         project_id = self.project_id or hook.project_id
         if project_id:
             CloudBuildListLink.persist(
-                context=context, task_instance=self, project_id=project_id, region=self.location
+                context=context,
+                project_id=project_id,
             )
         return [Build.to_dict(result) for result in results]
 
@@ -804,6 +836,12 @@ class CloudBuildRetryBuildOperator(GoogleCloudBaseOperator):
         self.impersonation_chain = impersonation_chain
         self.location = location
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "region": self.location,
+        }
+
     def execute(self, context: Context):
         hook = CloudBuildHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         result = hook.retry_build(
@@ -816,14 +854,12 @@ class CloudBuildRetryBuildOperator(GoogleCloudBaseOperator):
             location=self.location,
         )
 
-        self.xcom_push(context, key="id", value=result.id)
+        context["task_instance"].xcom_push(key="id", value=result.id)
         project_id = self.project_id or hook.project_id
         if project_id:
             CloudBuildLink.persist(
                 context=context,
-                task_instance=self,
                 project_id=project_id,
-                region=self.location,
                 build_id=result.id,
             )
         return Build.to_dict(result)
@@ -890,6 +926,12 @@ class CloudBuildRunBuildTriggerOperator(GoogleCloudBaseOperator):
         self.impersonation_chain = impersonation_chain
         self.location = location
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "region": self.location,
+        }
+
     def execute(self, context: Context):
         hook = CloudBuildHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         result = hook.run_build_trigger(
@@ -902,14 +944,12 @@ class CloudBuildRunBuildTriggerOperator(GoogleCloudBaseOperator):
             metadata=self.metadata,
             location=self.location,
         )
-        self.xcom_push(context, key="id", value=result.id)
+        context["task_instance"].xcom_push(key="id", value=result.id)
         project_id = self.project_id or hook.project_id
         if project_id:
             CloudBuildLink.persist(
                 context=context,
-                task_instance=self,
                 project_id=project_id,
-                region=self.location,
                 build_id=result.id,
             )
         return Build.to_dict(result)
@@ -973,6 +1013,12 @@ class CloudBuildUpdateBuildTriggerOperator(GoogleCloudBaseOperator):
         self.impersonation_chain = impersonation_chain
         self.location = location
 
+    @property
+    def extra_links_params(self) -> dict[str, Any]:
+        return {
+            "region": self.location,
+        }
+
     def execute(self, context: Context):
         hook = CloudBuildHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         result = hook.update_build_trigger(
@@ -984,14 +1030,12 @@ class CloudBuildUpdateBuildTriggerOperator(GoogleCloudBaseOperator):
             metadata=self.metadata,
             location=self.location,
         )
-        self.xcom_push(context, key="id", value=result.id)
+        context["task_instance"].xcom_push(key="id", value=result.id)
         project_id = self.project_id or hook.project_id
         if project_id:
             CloudBuildTriggerDetailsLink.persist(
                 context=context,
-                task_instance=self,
                 project_id=project_id,
-                region=self.location,
                 trigger_id=result.id,
             )
         return BuildTrigger.to_dict(result)
