@@ -42,7 +42,7 @@ from airflow.providers.google.common.deprecated import deprecated
 if TYPE_CHECKING:
     from google.api_core.retry import Retry
 
-    from airflow.utils.context import Context
+    from airflow.providers.common.compat.sdk import Context
 
 
 class AutoMLTrainingJobBaseOperator(GoogleCloudBaseOperator):
