@@ -20,12 +20,8 @@ from __future__ import annotations
 
 from typing import Any
 
-from airflow.exceptions import AirflowException, AirflowOptionalProviderFeatureException
-
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.exceptions import AirflowOptionalProviderFeatureException
+from airflow.providers.common.compat.sdk import AirflowException, BaseHook
 
 try:
     import plyvel
