@@ -42,13 +42,20 @@ else:
     from airflow.decorators import task  # type: ignore[attr-defined,no-redef]
 from airflow.providers.google.suite.hooks.drive import GoogleDriveHook
 from airflow.providers.google.suite.transfers.local_to_drive import LocalFilesystemToGoogleDriveOperator
-from airflow.utils.trigger_rule import TriggerRule
 
-from tests_common.test_utils.api_client_helpers import create_airflow_connection, delete_airflow_connection
+try:
+    from airflow.sdk import TriggerRule
+except ImportError:
+    # Compatibility for Airflow < 3.1
+    from airflow.utils.trigger_rule import TriggerRule  # type: ignore[no-redef,attr-defined]
+
+from system.google.gcp_api_client_helpers import create_airflow_connection, delete_airflow_connection
 
 DAG_ID = "local_to_drive"
 ENV_ID = os.environ.get("SYSTEM_TESTS_ENV_ID", "default")
 
+IS_COMPOSER = bool(os.environ.get("COMPOSER_ENVIRONMENT", ""))
+
 FILE_NAME_1 = "test1"
 FILE_NAME_2 = "test2"
 CONNECTION_ID = f"connection_{DAG_ID}_{ENV_ID}"
@@ -79,6 +86,7 @@ with DAG(
         create_airflow_connection(
             connection_id=connection_id,
             connection_conf=connection,
+            is_composer=IS_COMPOSER,
         )
 
     create_connection_task = create_connection(connection_id=CONNECTION_ID)
@@ -122,7 +130,7 @@ with DAG(
 
     @task(task_id="delete_connection")
     def delete_connection(connection_id: str) -> None:
-        delete_airflow_connection(connection_id=connection_id)
+        delete_airflow_connection(connection_id=connection_id, is_composer=IS_COMPOSER)
 
     delete_connection_task = delete_connection(connection_id=CONNECTION_ID)
 
